==> tiny-simple-register-0.0.2-20190919.091653-1-sources.jar: com/gymchina/tiny/register/configuration/TinyConfigurationRegistrar.java <==
package com.gymchina.tiny.register.configuration;

import java.util.ArrayList;
import java.util.List;

import com.gymchina.tiny.common.global.TinyCommon;
import com.gymchina.tiny.register.configuration.definition.TinyDataSourceBeanDefinition;
import com.gymchina.tiny.register.configuration.definition.TinySimpleBeanDefinition;

/**
 * @Title TinyConfigurationRegistrar
 * @Package com.gymchina.tiny.register.configuration
 * @author tangjunfeng
 * @date 2019年3月7日 下午4:25:55
 * @version V1.0
 */
public class TinyConfigurationRegistrar {

	private static TinyConfigurationRegistrar _this;

	public static TinyConfigurationRegistrar getInstance() {
		if (null == _this) {
			_this = new TinyConfigurationRegistrar();
			_this.beanDefinitions = new ArrayList<>();
		}
		return _this;
	}

	private List<TinySimpleBeanDefinition> beanDefinitions;

	public TinyConfigurationRegistrar addBean(TinySimpleBeanDefinition beanDefinition) {
		autoEnableForbiddenDataSourceConfiguration(beanDefinition);
		beanDefinitions.add(beanDefinition);
		return this;
	}

	public List<TinySimpleBeanDefinition> getBeanDefinitions() {
		return beanDefinitions;
	}

	private int dataSourceBeanDefinitionCnt = 0;

	/*
	 * auto using atomikos for multiple data sources, so must forbidden
	 * AutoDataSourceConfiguration and XADataSourceAutoConfiguration
	 */
	private void autoEnableForbiddenDataSourceConfiguration(TinySimpleBeanDefinition beanDefinition) {
		if (dataSourceBeanDefinitionCnt > 1)
			return;
		if (TinyDataSourceBeanDefinition.class.isAssignableFrom(beanDefinition.getClass())) {
			dataSourceBeanDefinitionCnt++;
		}
		if (dataSourceBeanDefinitionCnt > 1) {
			TinyCommon.tinyFrameworkRunners.add(new TinyForbiddenAutoDataSourceConfiguration());
		}

	}

}

==> tiny-simple-register-0.0.2-20190920.013732-10-sources.jar: com/gymchina/tiny/register/configuration/TinyConfigurationRegistrar.java <==
package com.gymchina.tiny.register.configuration;

import java.util.ArrayList;
import java.util.List;

import com.gymchina.tiny.common.global.TinyCommon;
import com.gymchina.tiny.register.configuration.definition.TinyDataSourceBeanDefinition;
import com.gymchina.tiny.register.configuration.definition.TinySimpleBeanDefinition;

/**
 * @Title TinyConfigurationRegistrar
 * @Package com.gymchina.tiny.register.configuration
 * @author tangjunfeng
 * @date 2019年3月7日 下午4:25:55
 * @version V1.0
 */
public class TinyConfigurationRegistrar {

	private static TinyConfigurationRegistrar _this;

	public static TinyConfigurationRegistrar getInstance() {
		if (null == _this) {
			_this = new TinyConfigurationRegistrar();
			_this.beanDefinitions = new ArrayList<>();
		}
		return _this;
	}

	private List<TinySimpleBeanDefinition> beanDefinitions;

	public TinyConfigurationRegistrar addBean(TinySimpleBeanDefinition beanDefinition) {
		autoEnableForbiddenDataSourceConfiguration(beanDefinition);
		beanDefinitions.add(beanDefinition);
		return this;
	}

	public List<TinySimpleBeanDefinition> getBeanDefinitions() {
		return beanDefinitions;
	}

	private int dataSourceBeanDefinitionCnt = 0;

	/*
	 * auto using atomikos for multiple data sources, so must forbidden
	 * AutoDataSourceConfiguration and XADataSourceAutoConfiguration
	 */
	private void autoEnableForbiddenDataSourceConfiguration(TinySimpleBeanDefinition beanDefinition) {
		if (dataSourceBeanDefinitionCnt >= 1)
			return;
		if (TinyDataSourceBeanDefinition.class.isAssignableFrom(beanDefinition.getClass())) {
			dataSourceBeanDefinitionCnt++;
		}
		if (dataSourceBeanDefinitionCnt >= 1) {
			TinyCommon.tinyFrameworkRunners.add(new TinyForbiddenAutoDataSourceConfiguration());
		}

	}

}
